@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,22 +8,22 @@
 #include "widgets/configureimmutablewidgetutils.h"
 using namespace PimCommon::ConfigureImmutableWidgetUtils;
 #include "autocorrection.h"
-#include "ui_autocorrectionwidget.h"
-#include "import/importlibreofficeautocorrection.h"
-#include "import/importkmailautocorrection.h"
 #include "import/importabstractautocorrection.h"
+#include "import/importkmailautocorrection.h"
+#include "import/importlibreofficeautocorrection.h"
+#include "ui_autocorrectionwidget.h"
 
 #include "settings/pimcommonsettings.h"
 #include <KPIMTextEdit/SelectSpecialCharDialog>
 #include <Libkdepim/LineEditCatchReturnKey>
 
-#include <KMessageBox>
 #include <KLocalizedString>
+#include <KMessageBox>
 
-#include <QTreeWidgetItem>
-#include <QMenu>
 #include <QFileDialog>
+#include <QMenu>
 #include <QPointer>
+#include <QTreeWidgetItem>
 
 using namespace PimCommon;
 
@@ -112,10 +112,10 @@ AutoCorrectionWidget::AutoCorrectionWidget(QWidget *parent)
     slotEnableDisableAbreviationList();
     slotEnableDisableTwoUpperEntry();
 
-    auto *menu = new QMenu(this);
+    auto menu = new QMenu(this);
     d->ui->importAutoCorrection->setMenu(menu);
 
-    QAction *act = new QAction(i18n("LibreOffice Autocorrection"), this);
+    auto act = new QAction(i18n("LibreOffice Autocorrection"), this);
     act->setData(QVariant::fromValue(AutoCorrectionWidget::LibreOffice));
     menu->addAction(act);
 
@@ -401,7 +401,7 @@ void AutoCorrectionWidget::removeAutocorrectEntry()
 
         QString findStr;
         if (below) {
-            //qCDebug(PIMCOMMON_LOG) << "below";
+            // qCDebug(PIMCOMMON_LOG) << "below";
             findStr = item->text(0);
             delete item;
             item = nullptr;
@@ -457,7 +457,7 @@ void AutoCorrectionWidget::enableAddRemoveButton()
 
 void AutoCorrectionWidget::setFindReplaceText(QTreeWidgetItem *item, int column)
 {
-    Q_UNUSED(column);
+    Q_UNUSED(column)
     d->ui->find->setText(item->text(0));
     d->ui->replace->setText(item->text(1));
 }
