@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,14 +7,14 @@
 #ifndef AUTOCORRECTIONTEST_H
 #define AUTOCORRECTIONTEST_H
 
-#include <QObject>
 #include <KSharedConfig>
+#include <QObject>
 class AutoCorrectionTest : public QObject
 {
     Q_OBJECT
 public:
     AutoCorrectionTest();
-    ~AutoCorrectionTest();
+    ~AutoCorrectionTest() override;
 
 private Q_SLOTS:
     void shouldHaveDefaultValue();
