@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,14 +7,15 @@
 #ifndef CONFIGUREPLUGINSLISTWIDGET_H
 #define CONFIGUREPLUGINSLISTWIDGET_H
 
-#include <QWidget>
 #include "pimcommon_export.h"
 #include <PimCommon/PluginUtil>
+#include <QWidget>
 
 #include <QTreeWidgetItem>
 class QTreeWidget;
 class QAction;
-namespace PimCommon {
+namespace PimCommon
+{
 /**
  * @brief The ConfigurePluginsListWidget class
  * @author Laurent Montel <montel@kde.org>
@@ -24,7 +25,7 @@ class PIMCOMMON_EXPORT ConfigurePluginsListWidget : public QWidget
     Q_OBJECT
 public:
     explicit ConfigurePluginsListWidget(QWidget *parent = nullptr);
-    ~ConfigurePluginsListWidget();
+    ~ConfigurePluginsListWidget() override;
 
     virtual void save();
     virtual void doLoadFromGlobalSettings();
@@ -60,11 +61,18 @@ protected:
         bool mEnableFromUserSettings;
     };
     void savePlugins(const QString &groupName, const QString &prefixSettingKey, const QVector<PluginItem *> &listItems);
-    void fillTopItems(const QVector<PimCommon::PluginUtilData> &lst, const QString &topLevelItemName, const QString &groupName, const QString &prefixKey, QVector<PluginItem *> &itemsList, const QString &configureGroupName = QString(), bool checkable = true);
+    void fillTopItems(const QVector<PimCommon::PluginUtilData> &lst,
+                      const QString &topLevelItemName,
+                      const QString &groupName,
+                      const QString &prefixKey,
+                      QVector<PluginItem *> &itemsList,
+                      const QString &configureGroupName = QString(),
+                      bool checkable = true);
     void resetToUserSettings(const QVector<PluginItem *> &items);
     void changeState(const QVector<PluginItem *> &items);
 
     QTreeWidget *mListWidget = nullptr;
+
 private:
     void slotConfigureClicked(QAction *act);
     bool mInitializeDone = false;
