@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,11 +7,12 @@
 #ifndef CUSTOMTOOLSWIDGETNG_H
 #define CUSTOMTOOLSWIDGETNG_H
 
-#include <QWidget>
 #include "pimcommon_export.h"
+#include <QWidget>
 class KToggleAction;
 class KActionCollection;
-namespace PimCommon {
+namespace PimCommon
+{
 class CustomToolsWidgetNgPrivate;
 class CustomToolsPlugin;
 class CustomToolsViewInterface;
@@ -24,7 +25,7 @@ class PIMCOMMON_EXPORT CustomToolsWidgetNg : public QWidget
     Q_OBJECT
 public:
     explicit CustomToolsWidgetNg(QWidget *parent = nullptr);
-    ~CustomToolsWidgetNg();
+    ~CustomToolsWidgetNg() override;
 
     Q_REQUIRED_RESULT QList<KToggleAction *> actionList() const;
     void initializeView(KActionCollection *ac, const QVector<CustomToolsPlugin *> &localPluginsList);
