@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,7 +9,8 @@
 
 #include "abstractgenericplugin.h"
 #include "pimcommon_export.h"
-namespace PimCommon {
+namespace PimCommon
+{
 /**
  * @brief The GenericPlugin class
  * @author Laurent Montel <montel@kde.org>
@@ -19,7 +20,7 @@ class PIMCOMMON_EXPORT GenericPlugin : public AbstractGenericPlugin
     Q_OBJECT
 public:
     explicit GenericPlugin(QObject *parent = nullptr);
-    ~GenericPlugin();
+    ~GenericPlugin() override;
 };
 }
 #endif // GENERICPLUGIN_H
