@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -8,17 +8,18 @@
 #ifndef BLACKLISTBALOOEMAILLIST_H
 #define BLACKLISTBALOOEMAILLIST_H
 
+#include "pimcommonakonadi_private_export.h"
+#include <QHash>
 #include <QListWidget>
 #include <QListWidgetItem>
-#include <QHash>
-#include "pimcommonakonadi_private_export.h"
 
-namespace PimCommon {
+namespace PimCommon
+{
 class PIMCOMMONAKONADI_TESTS_EXPORT BlackListBalooEmailListItem : public QListWidgetItem
 {
 public:
     explicit BlackListBalooEmailListItem(QListWidget *parent = nullptr);
-    ~BlackListBalooEmailListItem();
+    ~BlackListBalooEmailListItem() override;
 
     Q_REQUIRED_RESULT bool initializeStatus() const;
     void setInitializeStatus(bool initializeStatus);
@@ -40,6 +41,7 @@ public:
 
     void setExcludeDomain(const QStringList &domain);
     Q_REQUIRED_RESULT int setEmailFound(const QStringList &);
+
 protected:
     void paintEvent(QPaintEvent *event) override;
 
