@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -8,16 +8,17 @@
 #ifndef BLACKLISTBALOOEMAILWARNING_H
 #define BLACKLISTBALOOEMAILWARNING_H
 
-#include <KMessageWidget>
 #include "pimcommonakonadi_private_export.h"
+#include <KMessageWidget>
 
-namespace PimCommon {
+namespace PimCommon
+{
 class PIMCOMMONAKONADI_TESTS_EXPORT BlackListBalooEmailWarning : public KMessageWidget
 {
     Q_OBJECT
 public:
     explicit BlackListBalooEmailWarning(QWidget *parent = nullptr);
-    ~BlackListBalooEmailWarning();
+    ~BlackListBalooEmailWarning() override;
 
 Q_SIGNALS:
     void newSearch();
