@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -11,9 +11,9 @@
 #include <KLDAP/LdapClient>
 #include <KLDAP/LdapClientSearch>
 
-#include <KLDAP/LdapClientSearchConfig>
 #include <KContacts/Addressee>
 #include <KContacts/ContactGroup>
+#include <KLDAP/LdapClientSearchConfig>
 
 #include <AkonadiCore/ChangeRecorder>
 #include <AkonadiCore/CollectionFilterProxyModel>
@@ -24,12 +24,12 @@
 
 #include <KConfigGroup>
 #include <KLocalizedString>
-#include <QTreeWidget>
-#include <QTreeWidgetItem>
+#include <QDBusConnection>
 #include <QHBoxLayout>
 #include <QPushButton>
+#include <QTreeWidget>
+#include <QTreeWidgetItem>
 #include <QVBoxLayout>
-#include <QDBusConnection>
 
 using namespace PimCommon;
 
@@ -67,8 +67,7 @@ public:
     {
         KConfig *config = KLDAP::LdapClientSearchConfig::config();
         KConfigGroup group(config, "LDAP");
-        group.writeEntry(QStringLiteral("SelectedCompletionWeight%1").arg(mLdapClient->clientNumber()),
-                         mWeight);
+        group.writeEntry(QStringLiteral("SelectedCompletionWeight%1").arg(mLdapClient->clientNumber()), mWeight);
         group.sync();
     }
 
@@ -84,7 +83,7 @@ public:
 
     void setIsEnabled(bool b) override
     {
-        Q_UNUSED(b);
+        Q_UNUSED(b)
     }
 
 protected:
@@ -115,7 +114,7 @@ public:
         }
     }
 
-    ~SimpleCompletionItem()
+    ~SimpleCompletionItem() override
     {
     }
 
@@ -190,7 +189,7 @@ public:
         setItem(item);
     }
 
-    ~CompletionViewItem()
+    ~CompletionViewItem() override
     {
         delete mItem;
     }
@@ -216,7 +215,7 @@ public:
     bool operator<(const QTreeWidgetItem &other) const override
     {
         const QTreeWidgetItem *otherItem = &other;
-        const auto *completionItem = static_cast<const CompletionViewItem *>(otherItem);
+        const auto completionItem = static_cast<const CompletionViewItem *>(otherItem);
         // item with weight 100 should be on the top -> reverse sorting
         return mItem->completionWeight() > completionItem->item()->completionWeight();
     }
@@ -232,10 +231,10 @@ CompletionOrderWidget::CompletionOrderWidget(QWidget *parent)
     new CompletionOrderEditorAdaptor(this);
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/"), this, QDBusConnection::ExportAdaptors);
 
-    auto *hbox = new QHBoxLayout(this);
+    auto hbox = new QHBoxLayout(this);
 
-    QWidget *page = new QWidget(this);
-    auto *pageHBoxLayout = new QHBoxLayout(page);
+    auto page = new QWidget(this);
+    auto pageHBoxLayout = new QHBoxLayout(page);
     pageHBoxLayout->setContentsMargins(0, 0, 0, 0);
     hbox->addWidget(page);
     mListView = new QTreeWidget(page);
@@ -249,8 +248,8 @@ CompletionOrderWidget::CompletionOrderWidget(QWidget *parent)
     mListView->setHeaderHidden(true);
     mListView->setSortingEnabled(true);
 
-    QWidget *upDownBox = new QWidget(page);
-    auto *upDownBoxVBoxLayout = new QVBoxLayout(upDownBox);
+    auto upDownBox = new QWidget(page);
+    auto upDownBoxVBoxLayout = new QVBoxLayout(upDownBox);
     upDownBoxVBoxLayout->setContentsMargins(0, 0, 0, 0);
     pageHBoxLayout->addWidget(upDownBox);
     mUpButton = new QPushButton(upDownBox);
@@ -258,7 +257,7 @@ CompletionOrderWidget::CompletionOrderWidget(QWidget *parent)
     mUpButton->setAutoRepeat(true);
     mUpButton->setObjectName(QStringLiteral("mUpButton"));
     mUpButton->setIcon(QIcon::fromTheme(QStringLiteral("go-up")));
-    mUpButton->setEnabled(false);   // b/c no item is selected yet
+    mUpButton->setEnabled(false); // b/c no item is selected yet
     mUpButton->setToolTip(i18n("Move Up"));
     mUpButton->setFocusPolicy(Qt::StrongFocus);
 
@@ -267,20 +266,17 @@ CompletionOrderWidget::CompletionOrderWidget(QWidget *parent)
     mDownButton->setAutoRepeat(true);
     mDownButton->setObjectName(QStringLiteral("mDownButton"));
     mDownButton->setIcon(QIcon::fromTheme(QStringLiteral("go-down")));
-    mDownButton->setEnabled(false);   // b/c no item is selected yet
+    mDownButton->setEnabled(false); // b/c no item is selected yet
     mDownButton->setToolTip(i18n("Move Down"));
     mDownButton->setFocusPolicy(Qt::StrongFocus);
 
-    QWidget *spacer = new QWidget(upDownBox);
+    auto spacer = new QWidget(upDownBox);
     upDownBoxVBoxLayout->addWidget(spacer);
     upDownBoxVBoxLayout->setStretchFactor(spacer, 100);
 
-    connect(mListView, &QTreeWidget::itemSelectionChanged,
-            this, &CompletionOrderWidget::slotSelectionChanged);
-    connect(mListView, &QTreeWidget::currentItemChanged,
-            this, &CompletionOrderWidget::slotSelectionChanged);
-    connect(mListView, &QTreeWidget::itemChanged,
-            this, &CompletionOrderWidget::slotItemChanged);
+    connect(mListView, &QTreeWidget::itemSelectionChanged, this, &CompletionOrderWidget::slotSelectionChanged);
+    connect(mListView, &QTreeWidget::currentItemChanged, this, &CompletionOrderWidget::slotSelectionChanged);
+    connect(mListView, &QTreeWidget::itemChanged, this, &CompletionOrderWidget::slotItemChanged);
     connect(mUpButton, &QAbstractButton::clicked, this, &CompletionOrderWidget::slotMoveUp);
     connect(mDownButton, &QAbstractButton::clicked, this, &CompletionOrderWidget::slotMoveDown);
 }
@@ -293,13 +289,12 @@ void CompletionOrderWidget::save()
 {
     if (mDirty) {
         int w = 100;
-        //Clean up order
+        // Clean up order
         KConfigGroup group(configFile(), "CompletionWeights");
         group.deleteGroup();
 
         for (int itemIndex = 0; itemIndex < mListView->topLevelItemCount(); ++itemIndex) {
-            auto *item
-                = static_cast<CompletionViewItem *>(mListView->topLevelItem(itemIndex));
+            auto item = static_cast<CompletionViewItem *>(mListView->topLevelItem(itemIndex));
             item->item()->setCompletionWeight(w);
             item->item()->setIsEnabled(item->checkState(0) == Qt::Checked);
             item->item()->save(this);
@@ -316,8 +311,8 @@ KConfig *CompletionOrderWidget::configFile()
 
 void CompletionOrderWidget::addRecentAddressItem()
 {
-    //Be default it's the first.
-    SimpleCompletionItem *item = new SimpleCompletionItem(this, i18n("Recent Addresses"), QStringLiteral("Recent Addresses"), 10);
+    // Be default it's the first.
+    auto item = new SimpleCompletionItem(this, i18n("Recent Addresses"), QStringLiteral("Recent Addresses"), 10);
     item->setIcon(QIcon::fromTheme(QStringLiteral("kmail")));
     new CompletionViewItem(mListView, item);
 }
@@ -329,7 +324,7 @@ void CompletionOrderWidget::addCompletionItemForCollection(const QModelIndex &in
         return;
     }
 
-    SimpleCompletionItem *item = new SimpleCompletionItem(this, index.data().toString(), QString::number(collection.id()), mDefaultValue++, true);
+    auto item = new SimpleCompletionItem(this, index.data().toString(), QString::number(collection.id()), mDefaultValue++, true);
     item->setIcon(index.data(Qt::DecorationRole).value<QIcon>());
 
     new CompletionViewItem(mListView, item);
@@ -345,28 +340,27 @@ void CompletionOrderWidget::loadCompletionItems()
         }
     }
 
-    auto *monitor = new Akonadi::ChangeRecorder(this);
+    auto monitor = new Akonadi::ChangeRecorder(this);
     monitor->fetchCollection(true);
     monitor->setCollectionMonitored(Akonadi::Collection::root());
     monitor->setMimeTypeMonitored(KContacts::Addressee::mimeType(), true);
     monitor->setMimeTypeMonitored(KContacts::ContactGroup::mimeType(), true);
 
-    auto *model = new Akonadi::EntityTreeModel(monitor, this);
+    auto model = new Akonadi::EntityTreeModel(monitor, this);
     model->setItemPopulationStrategy(Akonadi::EntityTreeModel::NoItemPopulation);
 
-    auto *descendantsProxy = new KDescendantsProxyModel(this);
+    auto descendantsProxy = new KDescendantsProxyModel(this);
     descendantsProxy->setDisplayAncestorData(true);
     descendantsProxy->setSourceModel(model);
 
-    auto *mimeTypeProxy = new Akonadi::CollectionFilterProxyModel(this);
+    auto mimeTypeProxy = new Akonadi::CollectionFilterProxyModel(this);
     mimeTypeProxy->addMimeTypeFilters({KContacts::Addressee::mimeType(), KContacts::ContactGroup::mimeType()});
     mimeTypeProxy->setSourceModel(descendantsProxy);
     mimeTypeProxy->setExcludeVirtualCollections(true);
 
     mCollectionModel = mimeTypeProxy;
 
-    connect(mimeTypeProxy, &QAbstractItemModel::rowsInserted,
-            this, &CompletionOrderWidget::rowsInserted);
+    connect(mimeTypeProxy, &QAbstractItemModel::rowsInserted, this, &CompletionOrderWidget::rowsInserted);
     for (int row = 0; row < mCollectionModel->rowCount(); ++row) {
         addCompletionItemForCollection(mCollectionModel->index(row, 0));
     }
@@ -418,11 +412,11 @@ static void swapItems(CompletionViewItem *one, CompletionViewItem *other)
 
 void CompletionOrderWidget::slotMoveUp()
 {
-    auto *item = static_cast<CompletionViewItem *>(mListView->currentItem());
+    auto item = static_cast<CompletionViewItem *>(mListView->currentItem());
     if (!item) {
         return;
     }
-    auto *above = static_cast<CompletionViewItem *>(mListView->itemAbove(item));
+    auto above = static_cast<CompletionViewItem *>(mListView->itemAbove(item));
     if (!above) {
         return;
     }
@@ -434,11 +428,11 @@ void CompletionOrderWidget::slotMoveUp()
 
 void CompletionOrderWidget::slotMoveDown()
 {
-    auto *item = static_cast<CompletionViewItem *>(mListView->currentItem());
+    auto item = static_cast<CompletionViewItem *>(mListView->currentItem());
     if (!item) {
         return;
     }
-    auto *below = static_cast<CompletionViewItem *>(mListView->itemBelow(item));
+    auto below = static_cast<CompletionViewItem *>(mListView->itemBelow(item));
     if (!below) {
         return;
     }
