@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,17 +7,17 @@
 #ifndef ADDRESSESSLINEEDITABSTRACTPLUGIN_H
 #define ADDRESSESSLINEEDITABSTRACTPLUGIN_H
 
-#include <QObject>
 #include "pimcommonakonadi_export.h"
+#include <QObject>
 
-namespace PimCommon {
+namespace PimCommon
+{
 class AddresseeLineEdit;
 /**
  * @brief The AddressessLineEditAbstractPluginInfo struct
  * @author Laurent Montel <montel@kde.org>
  */
-struct PIMCOMMONAKONADI_EXPORT AddressessLineEditAbstractPluginInfo
-{
+struct PIMCOMMONAKONADI_EXPORT AddressessLineEditAbstractPluginInfo {
     QString name;
     QString identifier;
     QString description;
@@ -32,7 +32,7 @@ class PIMCOMMONAKONADI_EXPORT AddressessLineEditAbstractPlugin : public QObject
     Q_OBJECT
 public:
     explicit AddressessLineEditAbstractPlugin(QObject *parent = nullptr);
-    ~AddressessLineEditAbstractPlugin();
+    ~AddressessLineEditAbstractPlugin() override;
 
     void setLineEdit(PimCommon::AddresseeLineEdit *linedit);
 
