@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,15 +7,17 @@
 #ifndef IMAPRESOURCECAPABILITIESMANAGER_H
 #define IMAPRESOURCECAPABILITIESMANAGER_H
 
-#include <QObject>
 #include <QHash>
+#include <QObject>
 
 #include "pimcommonakonadi_export.h"
 class QDBusPendingCallWatcher;
-namespace Akonadi {
+namespace Akonadi
+{
 class AgentInstance;
 }
-namespace PimCommon {
+namespace PimCommon
+{
 /**
  * @brief The ImapResourceCapabilitiesManager class
  * @author Laurent Montel <montel@kde.org>
@@ -25,7 +27,7 @@ class PIMCOMMONAKONADI_EXPORT ImapResourceCapabilitiesManager : public QObject
     Q_OBJECT
 public:
     explicit ImapResourceCapabilitiesManager(QObject *parent = nullptr);
-    ~ImapResourceCapabilitiesManager();
+    ~ImapResourceCapabilitiesManager() override;
 
     Q_REQUIRED_RESULT bool hasAnnotationSupport(const QString &identifier) const;
 
